# Licensed under the GPL: https://www.gnu.org/licenses/gpl-3.0.en.html
# For details: reprotest/debian/copyright

import pytest

from reprotest.mdiffconf import *


class LolX(collections.namedtuple("LolX", "x y z")):
    pass

def test_basic():
    one = ImmutableNamespace(lol=LolX(x=strlist_set(";"), y=10, z=True), wtf=True)
    zero = ImmutableNamespace(lol=LolX(x=strlist_set(";", ['less than nothing yo!']), y=0, z=False), wtf=False)
    d = ImmutableNamespace()
    d = parse_all(d, '+lol,wtf,-xxx,lol.x+=4;5;6,lol.y+=123,lol.x-=5,-lol.z', one, zero, sep=",")
    assert d == ImmutableNamespace(lol=LolX(x=['4', '6'], y=133, z=False), wtf=True)
    d = parse_all(d, '@lol,-lol.x,-lol.z,lol.x+=3;4;5', one, zero, sep=",")
    assert d == ImmutableNamespace(lol=LolX(x=['less than nothing yo!', '3', '4', '5'], y=10, z=False), wtf=True)



#!/usr/bin/env python3

# Licensed under the GPL: https://www.gnu.org/licenses/gpl-3.0.en.html
# For details: reprotest/debian/copyright

from setuptools import setup, find_packages

setup(name='reprotest',
      version='0.7.14',
      description='Build packages and check them for reproducibility.',
      long_description=open('README.rst', encoding='utf-8').read(),
      author='Ximin Luo, Ceridwen',
      author_email='infinity0@debian.org, ceridwenv@gmail.com',
      license='GPL-3+',
      url='https://salsa.debian.org/reproducible-builds/reprotest',
      packages=find_packages(),
      entry_points={
          'console_scripts': [
              'reprotest = reprotest:main'
              ],
          },
      install_requires=[
          'diffoscope',
          'rstr',
          'distro',
          ],
      classifiers=[
          'Development Status :: 3 - Alpha',
          'Intended Audience :: Developers',
          'License :: OSI Approved :: GNU General Public License v3 or later (GPLv3+)',
          'Operating System :: POSIX',
          'Programming Language :: Python',
          'Programming Language :: Python :: 3',
          'Programming Language :: Python :: 3.7',
          'Topic :: Utilities',
          ],
      zip_safe=False,
      include_package_data=True
      )
